@@ -35,16 +35,14 @@ def build_spec(
     rank = model_files.summary_rank[0]
     rank_index = RANKS.index(rank)
     if strict:
-        ranks = RANKS[0:(rank_index + 1)]
+        ranks = RANKS[0 : (rank_index + 1)]
     else:
         ranks = [rank]
-    model_files["file"] = model_files[rank].apply(
-        lambda i: str(models.json_files.path_maker(model_id=i))
-    )
 
     tax = build_from_qiime(abundance, taxonomy, collapse_on=ranks)
     micom_taxonomy = pd.merge(model_files, tax, on=ranks)
     micom_taxonomy = micom_taxonomy[micom_taxonomy.relative > cutoff]
+    del micom_taxonomy["file"]
     stats = micom_taxonomy.sample_id.value_counts().describe()
     print("Merged with the database using ranks: %s" % ", ".join(ranks))
     print(
@@ -61,7 +59,7 @@ def build(
     threads: int = 1,
     cutoff: float = 0.0001,
     strict: bool = False,
-    solver: str = "auto"
+    solver: str = "auto",
 ) -> CommunityModelDirectory:
     """Build the community models."""
     if solver == "auto":
