@@ -2,6 +2,7 @@
 
 from micom.workflows.core import GrowthResults
 import micom.viz as viz
+from os.path import join
 import pandas as pd
 from qiime2 import MetadataColumn
 
@@ -10,7 +11,7 @@ def plot_growth(output_dir: str, results: GrowthResults) -> None:
     """Plot the taxa growth rates."""
     viz.plot_growth(
         results,
-        output_dir
+        join(output_dir, "index.html"),
     )
 
 
@@ -22,10 +23,7 @@ def exchanges_per_sample(
 ) -> None:
     """Plot the exchange fluxes."""
     viz.plot_exchanges_per_sample(
-        results,
-        output_dir,
-        direction,
-        cluster
+        results, join(output_dir, "index.html"), direction, cluster
     )
 
 
@@ -33,25 +31,20 @@ def exchanges_per_taxon(
     output_dir: str,
     results: GrowthResults,
     direction: str = "import",
-    n_neighbors: int = 15,
-    min_dist: float = 0.1,
+    perplexity: int = 20,
 ) -> None:
     """Plot the exchange fluxes."""
     viz.plot_exchanges_per_taxon(
         results,
-        output_dir,
+        join(output_dir, "index.html"),
         direction,
-        n_neighbors=n_neighbors,
-        min_dist=min_dist
+        perplexity=perplexity,
     )
 
 
 def plot_tradeoff(output_dir: str, results: pd.DataFrame) -> None:
     """Plot the taxa growth rates."""
-    viz.plot_tradeoff(
-        results,
-        output_dir
-    )
+    viz.plot_tradeoff(results, join(output_dir, "index.html"))
 
 
 def fit_phenotype(
@@ -60,7 +53,7 @@ def fit_phenotype(
     metadata: MetadataColumn,
     variable_type: str = "binary",
     flux_type: str = "production",
-    min_coef: float = 0.01,
+    min_coef: float = 0.001,
 ):
     """Test for differential metabolite production."""
     meta = metadata.to_series()
@@ -69,7 +62,8 @@ def fit_phenotype(
         meta,
         variable_type,
         meta.name,
-        output_dir,
+        join(output_dir, "index.html"),
         flux_type,
-        min_coef
+        min_coef,
+        atol=1e-6,
     )
